ML-Mnemonist is an open-source lightweight framework for simple ML operations and it pairs up easily with free online cloud services that do not support session backup and recovery because the framework implements these in the hardware level. To that end, some of the tutorials here are purposefully created to work with Google Colab.
<p align="center">
<img src="/figures/logo.png"/>
</p>

Check out more information on the GitHub <a href="https://github.com/HamidrezaKmK/ML-Mnemonist">repository</a>.